(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[489],{44876:function(n,u,t){(window.__NEXT_P=window.__NEXT_P||[]).push(["/account/upgrade",function(){return t(22788)}])},22788:function(n,u,t){"use strict";t.r(u),t.d(u,{__N_SSP:function(){return h},default:function(){return p}});var e=t(39324),o=t(35250),r=t(68555),c=t(70079),a=t(48432),i=t(97688),s=t(99060),f=t(64135),l=t(87316),d=t(82841),_=t(36218),h=!0;function p(n){return(0,o.jsx)(v,(0,e._)({},n))}function v(n){var u=n.user,t=n.isUserInCanPayGroup,e=n.serviceStatus,h=n.userCountry,p=n.cohort,v=(0,r.useRouter)(),g=(0,f.nR)(),E=(0,l.g)(function(n){return n.updateFlagValue});(0,c.useEffect)(function(){void 0!==t&&E("isUserInCanPayGroup",t)},[E,t]),(0,c.useEffect)(function(){(null==e?void 0:e.type)&&void 0!==g&&!g&&i.m.warning(e.message,{hasCloseButton:!0,duration:5})},[g,null==e?void 0:e.message,null==e?void 0:e.type]);var w=(0,c.useMemo)(function(){return{app:_.VY,origin:"chat"}},[]),y={};p&&(y.email_cohort=p),(0,s.Z)("ChatGPT",u,w,y);var P=(0,c.useCallback)(function(){v.push("/")},[v]);return(0,o.jsx)(d.Af.Provider,{value:w,children:(0,o.jsx)(C,{cohort:p,userCountry:h,children:(0,o.jsx)(a.Z,{isOpen:!0,onClose:P})})})}var C=function(n){var u=n.children,t=n.cohort,e=n.userCountry,o=(0,d.WS)();return(0,c.useEffect)(function(){t&&o(_.s6.accountUpgradeFullpageLoaded,{content:"Email Cohort: ".concat(t),tags:["actual_location:".concat(e)]})},[o,t,e]),u}}},function(n){n.O(0,[58,774,888,179],function(){return n(n.s=44876)}),_N_E=n.O()}]);